.. _debops.apt_preferences:

debops.apt_preferences
======================

.. toctree::
   :maxdepth: 2

   introduction
   getting-started
   defaults/main
   defaults-detailed
   copyright

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
